<?php
/**
* Joomla Community Builder Ratio Field Type Plugin: plug_cbratiofield
* @version $Id$
* @package plug_cbratiofield
* @subpackage cb.ratiofield.php
* @author Joe Palmer
* @copyright (C) 2009 www.softforge.co.uk
* @license Limited http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU/GPL version 2
* @final 1.0
*/

/** ensure this file is being included by a parent file */
if ( ! ( defined( '_VALID_CB' ) || defined( '_JEXEC' ) || defined( '_VALID_MOS' ) ) ) { die( 'Direct Access to this location is not allowed.' ); }

global $_PLUGINS;
$_PLUGINS->loadPluginGroup( 'user', array( (int) 1 ) );
$_PLUGINS->registerUserFieldTypes( array( 'ratiofield' => 'CBfield_ratio' ) );
$_PLUGINS->registerUserFieldParams();

class CBfield_ratio extends CBfield_counter {
	/**
	 * Returns a field in specified format
	 *
	 * @param  moscomprofilerFields  $field
	 * @param  moscomprofilerUser    $user
	 * @param  string                $output  'html', 'xml', 'json', 'php', 'csvheader', 'csv', 'rss', 'fieldslist', 'htmledit'
	 * @param  string                $reason  'profile' for user profile view, 'edit' for profile edit, 'register' for registration, 'list' for user-lists
	 * @param  int                   $list_compare_types   IF reason == 'search' : 0 : simple 'is' search, 1 : advanced search with modes, 2 : simple 'any' search
	 * @return mixed                
	 */
	function getField( &$field, &$user, $output, $reason, $list_compare_types ) {

		$oReturn							=	null;
			
		$fieldname1 = $field->params->get( 'fieldName1', 'hits' );
        $fieldname2 = $field->params->get( 'fieldName2', 'message_number_sent' );
        $ratiotype = $field->params->get( 'fieldRatioType', 'decimal' );
        $decimals = $field->params->get( 'fieldDecimalLength', '1' );
        $fractiontype = $field->params->get( 'fieldFractionType', 'yes' );
        $fractionseparator = $field->params->get( 'fieldFractionSeparator', '/' );
        
		$field1 = $user->$fieldname1;
		$field2 = $user->$fieldname2;

		// Calculate ratio
		if ( is_numeric($field1) && is_numeric($field2) ) {
		    if ( $ratiotype == "decimal" ) {
			    $value = round($field1/$field2, $decimals);
		    } elseif ( $ratiotype == "percentage" ) {
                $value = round(($field1/$field2)*100, $decimals) . "%";
            } else {
		    	if ( $fractiontype == "yes" ) {
			        $gcd = gmp_strval(gmp_gcd($field1, $field2));
			        $value = $field1/$gcd . $fractionseparator . $field2/$gcd;
		    	} else {
		    		$value = $field1 . $fractionseparator . $field2;
		    	}
		    }
		} else {
			$value = null;
		}
		
		switch ( $output ) {
			case 'html':
			case 'rss':
				$oReturn				=	$value;
				break;
	
			case 'htmledit':
				// $oReturn				=	parent::getField( $field, $user, $output, $reason, $list_compare_types );
				$oReturn				=	null;		//TBD for now no searches...not optimal in SQL anyway.
				break;

			case 'json':
			case 'php':
			case 'xml':
			case 'csvheader':
			case 'fieldslist':
			case 'csv':
			default:
				$oReturn				=	$this->_formatFieldOutputIntBoolFloat( $field->name, $value, $output );
				break;
		}
		return $oReturn;
	}
}//end of ratio field
?>